@@ -8,12 +8,12 @@ sr <- function(schedule, population) {
   R0 <- 1
 
   sr <- with(schedule, {
-    phi <- sum(Fecundity * Spawning/2 * Survivorship)
+    phi <- sum(Fecundity * Spawning / 2 * Survivorship)
 
-    phiF <- sum(Fecundity * Spawning/2 * FishedSurvivorship)
+    phiF <- sum(Fecundity * Spawning / 2 * FishedSurvivorship)
 
-    alpha <-  Rk / phi
-    if(BH) {
+    alpha <- Rk / phi
+    if (BH) {
       beta <- (alpha * phi - 1) / (R0 * phi)
       kappa <- alpha / beta
       R0F <- (alpha * phiF - 1) / (beta * phiF)
@@ -27,11 +27,13 @@ sr <- function(schedule, population) {
     R0F <- R0F / kappa * Rmax
     S0 <- sum(Spawning * Survivorship * R0)
     S0F <- sum(Spawning * FishedSurvivorship * R0F)
-    sr <- data.frame(alpha = alpha, beta = beta,
-               Rk = Rk,
-               phi = phi, phiF = phiF,
-               R0 = R0, R0F = R0F,
-               S0 = S0, S0F = S0F)
+    sr <- data.frame(
+      alpha = alpha, beta = beta,
+      Rk = Rk,
+      phi = phi, phiF = phiF,
+      R0 = R0, R0F = R0F,
+      S0 = S0, S0F = S0F
+    )
   })
   as_tibble(sr)
 }
@@ -48,19 +50,22 @@ sr <- function(schedule, population) {
 #'   \item{R0}{Age tR recruits at the unfished equilibrium}
 #'   \item{R0F}{Age tR recruits at the fished equilibrium}
 #'   \item{S0}{Spawners at the unfished equilibrium}
-#'   \item{S0F}{spawners at the fished equilibrium}
+#'   \item{S0F}{Spawners at the fished equilibrium}
 #' }
 #'
-#' @inheritParams ypr_schedule
+#' @inheritParams params
 #' @return A data frame of the SR parameters.
 #' @export
 #' @examples
 #' ypr_sr(ypr_population()) # Beverton-Holt
 #' ypr_sr(ypr_population(BH = 0L)) # Ricker
 ypr_sr <- function(population) {
-  check_population(population)
+  chk_population(population)
 
-  schedule <- ypr_schedule(population)
+  schedule <- ypr_tabulate_schedule(population)
 
-  sr(schedule, population)
+  sr <- sr(schedule, population)
+  sr$R0F <- max(sr$R0F, 0)
+  sr$S0F <- max(sr$S0F, 0)
+  sr
 }
